build_mc_kubeconfig_secret

Function build_mc_kubeconfig_secret 

pub fn build_mc_kubeconfig_secret(
    namespace: &str,
    sa_name: &str,
    kubeconfig_yaml: &str,
) -> Secret
Build the bindy.firestoned.io/remote-kubeconfig Secret containing the kubeconfig YAML.

The kubeconfig is stored under the kubeconfig key in data. Copy this Secret to the queen-ship cluster to grant the operator access to the remote child cluster.