pub enum RecordRef {
A(String, String),
AAAA(String, String),
CNAME(String, String),
TXT(String, String),
MX(String, String),
NS(String, String),
SRV(String, String),
CAA(String, String),
}Expand description
Enum representing a reference to any DNS record type.
This enum provides a type-safe way to reference records of different types in a unified collection. Each variant contains the name and namespace of the record.
Variants
A(String, String)
A record (IPv4 address)
AAAA(String, String)
AAAA record (IPv6 address)
CNAME(String, String)
CNAME record (canonical name)
TXT(String, String)
TXT record (text data)
MX(String, String)
MX record (mail exchange)
NS(String, String)
NS record (name server)
SRV(String, String)
SRV record (service locator)
CAA(String, String)
CAA record (certificate authority authorization)
Implementations