pub struct BindcarConfig {
pub image: Option<String>,
pub image_pull_policy: Option<String>,
pub resources: Option<ResourceRequirements>,
pub port: Option<i32>,
pub service_spec: Option<ServiceSpec>,
pub log_level: Option<String>,
pub env_vars: Option<Vec<EnvVar>>,
pub volumes: Option<Vec<Volume>>,
pub volume_mounts: Option<Vec<VolumeMount>>,
}Expand description
Bindcar container configuration
Fields
image: Option<String>Container image for the RNDC API sidecar
Example: “ghcr.io/firestoned/bindcar:v0.5.1”
image_pull_policy: Option<String>Image pull policy (Always, IfNotPresent, Never)
resources: Option<ResourceRequirements>Resource requirements for the Bindcar container
port: Option<i32>API server container port (default: 8080)
service_spec: Option<ServiceSpec>Custom Kubernetes Service spec for the bindcar HTTP API
Allows full customization of the Service that exposes the bindcar API. This is merged with the default Service spec, allowing overrides of ports, type, sessionAffinity, and other Service configurations.
Example:
serviceSpec:
type: NodePort
ports:
- name: http
port: 8000
targetPort: 8080
nodePort: 30080log_level: Option<String>Log level for the Bindcar container (debug, info, warn, error)
env_vars: Option<Vec<EnvVar>>Environment variables for the Bindcar container
volumes: Option<Vec<Volume>>Volumes that can be mounted by the Bindcar container
volume_mounts: Option<Vec<VolumeMount>>Volume mounts for the Bindcar container