delete_bind9instance

Function delete_bind9instance 

pub async fn delete_bind9instance(
    ctx: Arc<Context>,
    instance: Bind9Instance,
) -> Result<()>
Delete handler for Bind9Instance resources (cleanup logic).

This function is kept for backward compatibility but deletion is now handled by the finalizer in reconcile_bind9instance.

Errors

This function currently never returns an error, but returns Result for API consistency.