Struct Pod
pub struct Pod {
pub metadata: ObjectMeta,
pub spec: Option<PodSpec>,
pub status: Option<PodStatus>,
}Expand description
Pod is a collection of containers that can run on a host. This resource is created by clients and scheduled onto hosts.
Fields
metadata: ObjectMetaStandard object’s metadata. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#metadata
spec: Option<PodSpec>Specification of the desired behavior of the pod. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#spec-and-status
status: Option<PodStatus>Most recently observed status of the pod. This data may not be up to date. Populated by the system. Read-only. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#spec-and-status