refetch_zone

Function refetch_zone 

pub async fn refetch_zone(
    client: &Client,
    namespace: &str,
    name: &str,
) -> Result<DNSZone>
Re-fetch a DNSZone to get the latest status.

The dnszone parameter from the watch event might have stale status from the cache. We need the latest status.bind9Instances which may have been updated by the Bind9Instance reconciler.

Arguments

  • client - Kubernetes client
  • namespace - Namespace of the DNSZone
  • name - Name of the DNSZone

Returns

The freshly fetched DNSZone with current status

Errors

Returns an error if the Kubernetes API call fails