find_all_primary_pods

Function find_all_primary_pods 

pub async fn find_all_primary_pods(
    client: &Client,
    namespace: &str,
    cluster_name: &str,
    is_cluster_provider: bool,
) -> Result<Vec<PodInfo>>
Find all PRIMARY pods for a given cluster or cluster provider.

Returns pod information including name, IP, instance name, and namespace for all running PRIMARY pods in the cluster.

Arguments

  • client - Kubernetes API client
  • namespace - Namespace to search in (if not cluster provider)
  • cluster_name - Name of the cluster
  • is_cluster_provider - Whether to search across all namespaces

Returns

Vector of PodInfo for all running PRIMARY pods

Errors

Returns an error if Kubernetes API operations fail