is_resource_ready

Function is_resource_ready 

pub fn is_resource_ready(status: &Option<RecordStatus>) -> bool
Check if a resource with status conditions is ready.

A resource is considered ready if it has a status with at least one condition where type=“Ready” and status=“True”.

Arguments

  • status - Optional status containing conditions

Returns

true if the resource is ready, false otherwise