pub fn build_arecord(params: ARecordParams<'_>) -> ARecordExpand description
Builds the ARecord CR that Scout will create on the target cluster.
pub fn build_arecord(params: ARecordParams<'_>) -> ARecordBuilds the ARecord CR that Scout will create on the target cluster.