run_scout

Function run_scout 

pub async fn run_scout(
    cli_cluster_name: Option<String>,
    cli_namespace: Option<String>,
    cli_default_ips: Vec<String>,
    cli_default_zone: Option<String>,
) -> Result<()>
Entry point for the bindy scout subcommand.

Initialises the Kubernetes client, builds reflector stores for DNSZone resources (for zone validation), then runs the Ingress controller loop.

Errors

Returns an error if the Kubernetes client cannot be initialised or if the cluster name is not provided via CLI or the BINDY_SCOUT_CLUSTER_NAME env var.