pub struct GatewayStatus {
pub addresses: Option<Vec<GatewayStatusAddress>>,
}Expand description
Minimal Gateway status — only the assigned addresses.
Fields
addresses: Option<Vec<GatewayStatusAddress>>Addresses the controller has assigned to this Gateway (often empty when the controller publishes the external IP only on its LoadBalancer Service).