pub struct HTTPRoute {
pub api_version: String,
pub kind: String,
pub metadata: ObjectMeta,
pub spec: Option<HTTPRouteSpec>,
}Expand description
Minimal HTTPRoute definition for Scout’s use case.
Fields
api_version: Stringkind: Stringmetadata: ObjectMetaspec: Option<HTTPRouteSpec>Trait Implementations
Sourceimpl<'de> Deserialize<'de> for HTTPRoute
impl<'de> Deserialize<'de> for HTTPRoute
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl Metadata for HTTPRoute
impl Metadata for HTTPRoute
Sourcetype Ty = ObjectMeta
type Ty = ObjectMeta
The type of the metadata object.
Sourcefn metadata(&self) -> &ObjectMeta
fn metadata(&self) -> &ObjectMeta
Gets a reference to the metadata of this resource value.
Sourcefn metadata_mut(&mut self) -> &mut ObjectMeta
fn metadata_mut(&mut self) -> &mut ObjectMeta
Gets a mutable reference to the metadata of this resource value.
Sourceimpl Resource for HTTPRoute
impl Resource for HTTPRoute
Sourceconst API_VERSION: &'static str = "gateway.networking.k8s.io/v1"
const API_VERSION: &'static str = "gateway.networking.k8s.io/v1"
The API version of the resource. This is a composite of [
Resource::GROUP] and [Resource::VERSION] (eg "apiextensions.k8s.io/v1beta1")
or just the version for resources without a group (eg "v1"). Read moreSourceconst GROUP: &'static str = "gateway.networking.k8s.io"
const GROUP: &'static str = "gateway.networking.k8s.io"
The group of the resource, or the empty string if the resource doesn’t have a group.
Sourceconst URL_PATH_SEGMENT: &'static str = "httproutes"
const URL_PATH_SEGMENT: &'static str = "httproutes"
The URL path segment used to construct URLs related to this resource. Read more