pub async fn zone_exists(
client: &Arc<Client>,
token: Option<&str>,
zone_name: &str,
server: &str,
) -> Result<bool>Expand description
Check if a zone exists by trying to get its status.
Returns Ok(true) if the zone exists and can be queried, Ok(false) if the zone
definitely does not exist (404), or Err for transient errors (rate limiting, network
errors, server errors, etc.) that should be retried.
Errors
Returns an error if:
- The server is rate limiting requests (429 Too Many Requests)
- Network connectivity issues occur
- The server returns a 5xx error
- Any other non-404 error occurs