pub enum DNSRecordKind {
A,
AAAA,
TXT,
CNAME,
MX,
NS,
SRV,
CAA,
}Expand description
DNS record kind (type) enumeration.
Represents the Kubernetes kind field for all DNS record custom resources.
This enum eliminates magic strings when matching record types and provides
type-safe conversions between string representations and enum values.
Example
ⓘ
use bindy::crd::DNSRecordKind;
// Parse from string
let kind = DNSRecordKind::from("ARecord");
assert_eq!(kind, DNSRecordKind::A);
// Convert to string
assert_eq!(kind.as_str(), "ARecord");Variants
A
IPv4 address record (A)
AAAA
IPv6 address record (AAAA)
TXT
Text record (TXT)
CNAME
Canonical name record (CNAME)
MX
Mail exchange record (MX)
NS
Nameserver record (NS)
SRV
Service record (SRV)
CAA
Certificate authority authorization record (CAA)
Implementations
Sourceimpl DNSRecordKind
impl DNSRecordKind
Sourcepub const fn to_hickory_record_type(self) -> RecordType
pub const fn to_hickory_record_type(self) -> RecordType
Converts this DNS record kind to a Hickory DNS RecordType.
This is useful when interfacing with the Hickory DNS library for zone file generation or DNS protocol operations.
Example
ⓘ
use bindy::crd::DNSRecordKind;
use hickory_client::rr::RecordType;
let kind = DNSRecordKind::A;
let record_type = kind.to_hickory_record_type();
assert_eq!(record_type, RecordType::A);Trait Implementations
Sourceimpl Clone for DNSRecordKind
impl Clone for DNSRecordKind
Sourcefn clone(&self) -> DNSRecordKind
fn clone(&self) -> DNSRecordKind
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for DNSRecordKind
impl Debug for DNSRecordKind
Sourceimpl Display for DNSRecordKind
impl Display for DNSRecordKind
Sourceimpl From<&str> for DNSRecordKind
impl From<&str> for DNSRecordKind
Sourceimpl From<String> for DNSRecordKind
impl From<String> for DNSRecordKind
Sourceimpl Hash for DNSRecordKind
impl Hash for DNSRecordKind
Sourceimpl PartialEq for DNSRecordKind
impl PartialEq for DNSRecordKind
impl Copy for DNSRecordKind
impl Eq for DNSRecordKind
impl StructuralPartialEq for DNSRecordKind