Struct ConfigMap
pub struct ConfigMap {
pub binary_data: Option<BTreeMap<String, ByteString>>,
pub data: Option<BTreeMap<String, String>>,
pub immutable: Option<bool>,
pub metadata: ObjectMeta,
}Expand description
ConfigMap holds configuration data for pods to consume.
Fields
binary_data: Option<BTreeMap<String, ByteString>>BinaryData contains the binary data. Each key must consist of alphanumeric characters, ‘-’, ‘_’ or ‘.’. BinaryData can contain byte sequences that are not in the UTF-8 range. The keys stored in BinaryData must not overlap with the ones in the Data field, this is enforced during validation process. Using this field will require 1.10+ apiserver and kubelet.
data: Option<BTreeMap<String, String>>Data contains the configuration data. Each key must consist of alphanumeric characters, ‘-’, ‘_’ or ‘.’. Values with non-UTF-8 byte sequences must use the BinaryData field. The keys stored in Data must not overlap with the keys in the BinaryData field, this is enforced during validation process.
immutable: Option<bool>Immutable, if set to true, ensures that data stored in the ConfigMap cannot be updated (only object metadata can be modified). If not set to true, the field can be modified at any time. Defaulted to nil.
metadata: ObjectMetaStandard object’s metadata. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#metadata