Struct ListParams
pub struct ListParams {
pub label_selector: Option<String>,
pub field_selector: Option<String>,
pub timeout: Option<u32>,
pub limit: Option<u32>,
pub continue_token: Option<String>,
pub version_match: Option<VersionMatch>,
pub resource_version: Option<String>,
}Expand description
Common query parameters used in list/delete calls on collections
Fields
label_selector: Option<String>A selector to restrict the list of returned objects by their labels.
Defaults to everything if None.
field_selector: Option<String>A selector to restrict the list of returned objects by their fields.
Defaults to everything if None.
timeout: Option<u32>Timeout for the list/watch call.
This limits the duration of the call, regardless of any activity or inactivity.
limit: Option<u32>Limit the number of results.
If there are more results, the server will respond with a continue token which can be used to fetch another page of results. See the Kubernetes API docs for pagination details.
continue_token: Option<String>Fetch a second page of results.
After listing results with a limit, a continue token can be used to fetch another page of results.
version_match: Option<VersionMatch>Determines how resourceVersion is matched applied to list calls.
resource_version: Option<String>An explicit resourceVersion using the given VersionMatch strategy
See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
Implementations
impl ListParams
Builder interface to ListParams
impl ListParams
Builder interface to ListParams
Usage:
use kube::api::ListParams;
let lp = ListParams::default()
.match_any()
.timeout(60)
.labels("kubernetes.io/lifecycle=spot");pub fn timeout(self, timeout_secs: u32) -> ListParams
pub fn timeout(self, timeout_secs: u32) -> ListParams
Configure the timeout for list/watch calls
This limits the duration of the call, regardless of any activity or inactivity. Defaults to 290s
pub fn fields(self, field_selector: &str) -> ListParams
pub fn fields(self, field_selector: &str) -> ListParams
Configure the selector to restrict the list of returned objects by their fields.
Defaults to everything.
Supports =, ==, !=, and can be comma separated: key1=value1,key2=value2.
The server only supports a limited number of field queries per type.
pub fn labels(self, label_selector: &str) -> ListParams
pub fn labels(self, label_selector: &str) -> ListParams
Configure the selector to restrict the list of returned objects by their labels.
Defaults to everything.
Supports =, ==, !=, and can be comma separated: key1=value1,key2=value2.
pub fn labels_from(self, selector: &Selector) -> ListParams
pub fn labels_from(self, selector: &Selector) -> ListParams
Configure typed label selectors
Configure typed selectors from Selector and Expression lists.
use kube::core::{Expression, Selector, ParseExpressionError};
use k8s_openapi::apimachinery::pkg::apis::meta::v1::LabelSelector;
// From expressions
let selector: Selector = Expression::In("env".into(), ["development".into(), "sandbox".into()].into()).into();
let lp = ListParams::default().labels_from(&selector);
let lp = ListParams::default().labels_from(&Expression::Exists("foo".into()).into());
// Native LabelSelector
let selector: Selector = LabelSelector::default().try_into()?;
let lp = ListParams::default().labels_from(&selector);pub fn limit(self, limit: u32) -> ListParams
pub fn limit(self, limit: u32) -> ListParams
Sets a result limit.
pub fn continue_token(self, token: &str) -> ListParams
pub fn continue_token(self, token: &str) -> ListParams
Sets a continue token.
pub fn at(self, resource_version: &str) -> ListParams
pub fn at(self, resource_version: &str) -> ListParams
Sets the resource version
pub fn matching(self, version_match: VersionMatch) -> ListParams
pub fn matching(self, version_match: VersionMatch) -> ListParams
Sets an arbitary resource version match strategy
A non-default strategy such as VersionMatch::Exact or VersionMatch::NotOlderThan
requires an explicit resource_version set to pass request validation.
pub fn match_any(self) -> ListParams
pub fn match_any(self) -> ListParams
Use the semantic “any” resource version strategy
This is a less taxing variant of the default list, returning data at any resource version. It will prefer the newest avialable resource version, but strong consistency is not required; data at any resource version may be served. It is possible for the request to return data at a much older resource version than the client has previously observed, particularly in high availability configurations, due to partitions or stale caches. Clients that cannot tolerate this should not use this semantic.