Struct OwnerReference
pub struct OwnerReference {
pub api_version: String,
pub block_owner_deletion: Option<bool>,
pub controller: Option<bool>,
pub kind: String,
pub name: String,
pub uid: String,
}Expand description
OwnerReference contains enough information to let you identify an owning object. An owning object must be in the same namespace as the dependent, or be cluster-scoped, so there is no namespace field.
Fields
api_version: StringAPI version of the referent.
block_owner_deletion: Option<bool>If true, AND if the owner has the “foregroundDeletion” finalizer, then the owner cannot be deleted from the key-value store until this reference is removed. See https://kubernetes.io/docs/concepts/architecture/garbage-collection/#foreground-deletion for how the garbage collector interacts with this field and enforces the foreground deletion. Defaults to false. To set this field, a user needs “delete” permission of the owner, otherwise 422 (Unprocessable Entity) will be returned.
controller: Option<bool>If true, this reference points to the managing controller.
kind: StringKind of the referent. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#types-kinds
name: StringName of the referent. More info: https://kubernetes.io/docs/concepts/overview/working-with-objects/names#names
uid: StringUID of the referent. More info: https://kubernetes.io/docs/concepts/overview/working-with-objects/names#uids