add_dnszone

Function add_dnszone 

pub async fn add_dnszone(
    ctx: Arc<Context>,
    dnszone: DNSZone,
    zone_manager: &Bind9Manager,
    status_updater: &mut DNSZoneStatusUpdater,
    instance_refs: &[InstanceReference],
) -> Result<usize>
Adds a DNS zone to all primary instances.

Arguments

  • client - Kubernetes API client
  • dnszone - The DNSZone resource
  • zone_manager - BIND9 manager for adding zone

Returns

  • Ok(usize) - Number of primary endpoints successfully configured
  • Err(_) - If zone addition failed

Errors

Returns an error if BIND9 zone addition fails or if no instances are assigned.

Panics

Panics if the RNDC key is not loaded by the helper function (should never happen in practice).