Function detect_spec_changes
Source pub fn detect_spec_changes(zone: &DNSZone) -> (bool, bool)
Detect if the zone spec has changed since last reconciliation.
Compares current generation with observed generation to determine
if this is first reconciliation or if spec changed.
Arguments
zone - The DNSZone resource
Returns
Tuple of (first_reconciliation, spec_changed)