pub async fn reconcile_cname_record(
ctx: Arc<Context>,
record: CNAMERecord,
) -> Result<()>Expand description
Reconciles a CNAMERecord (canonical name alias) resource.
This is a thin wrapper around the generic reconcile_record<T>() function.
It finds DNSZones that have selected this record via label selectors and
creates/updates the record in BIND9 primaries for those zones using dynamic DNS updates.
Errors
Returns an error if Kubernetes API operations fail or BIND9 record creation fails.