pub enum VolumeRejection {
ForbiddenSource {
name: String,
kind: &'static str,
},
SecretNamePrefix {
name: String,
secret: String,
},
ConfigMapNamePrefix {
name: String,
config_map: String,
},
PvcNamePrefix {
name: String,
pvc: String,
},
MountPathOutsideAllowList {
path: String,
},
SubPathTraversal {
field: &'static str,
value: String,
},
}Expand description
Rejection reasons returned by validate_user_volumes and
validate_user_volume_mounts.
Each variant carries enough context for the reconciler to render a clear status condition on the offending CR.
Variants
ForbiddenSource
SecretNamePrefix
ConfigMapNamePrefix
PvcNamePrefix
MountPathOutsideAllowList
SubPathTraversal